# WARNING: This package is synced with FC

%if 0%{?fedora}
%bcond_without mdns
%bcond_without braille
%else
%bcond_without mdns
%bcond_with braille
%endif

# we build CUPS also with relro
%global _hardened_build 1

%define major     1
%define libname   %mklibname %{name} %{major}
%define develname %mklibname %{name} -d

Summary: OpenPrinting CUPS filters and backends
Name:    cups-filters
Version: 2.0.0
Release: %mkrel 1

# the CUPS exception text is the same as LLVM exception, so using that name with
# agreement from legal team
# https://lists.fedoraproject.org/archives/list/legal@lists.fedoraproject.org/message/A7GFSD6M3GYGSI32L2FC5KB22DUAEQI3/
License: Apache-2.0 WITH LLVM-exception

Group:   System/Printing
Url:     https://github.com/OpenPrinting/cups-filters
Source0: %{URL}/releases/download/%{version}/%{name}-%{version}.tar.gz
Source1: lftocrlf.ppd
Source2: lftocrlf

# autogen.sh
BuildRequires:  autoconf
# autogen.sh
BuildRequires:  automake
# filter binaries and backends are written in C
BuildRequires:  gcc
# autogen.sh
BuildRequires:  gettext-devel
# for autosetup
BuildRequires:  git-core
# autogen.sh
BuildRequires:  libtool
# uses make for compiling
BuildRequires:  make
# we use pkgconfig to get a proper devel packages
# proper CFLAGS and LDFLAGS
BuildRequires:  pkgconf-pkg-config
# uses CUPS API
BuildRequires:  pkgconfig(cups) >= 2.2.2
# uses cupsfilters API
BuildRequires:  pkgconfig(libcupsfilters) >= 2.0b3
# uses PPD API
BuildRequires:  pkgconfig(libppd) >= 2.0b3
# Make sure we get postscriptdriver tags.
BuildRequires:  python3-cups

%if %{with braille}
Recommends:     braille-printer-app
%endif
# needs cups dirs
Requires:       cups-filesystem

%description
Contains backends, filters, and other software that was
once part of the core CUPS distribution but is no longer maintained by
Apple Inc. In addition it contains additional filters developed
independently of Apple, especially filters for the PDF-centric printing
workflow introduced by OpenPrinting.

%package driverless
Summary:        OpenPrinting driverless backends and drivers for CUPS 2.X
License:        Apache-2.0 WITH LLVM-exception

# backends and drivers has been moved from the main package to subpackage
# to remove the avahi/mdns dependency needed for driverless
# remove after F40 is EOL and C10S is released
Conflicts:      cups-filters < 2.0.0

# finding device via driverless depends on running avahi-daemon
Requires:       avahi
# ippfind is used in driverless backend, not needed classic PPD based print queue
Requires:       cups-ipptool
# cups-browsed needs systemd-resolved or nss-mdns for resolving .local addresses of remote print queues
# let's not require a specific package and let the user decide what he wants to use.
# just recommend nss-mdns for Fedora for now to have working default, but
# don't hardwire it for resolved users
%if %{with mdns}
Recommends:     nss_mdns
%endif

# needs cups dirs
Requires:       cups-filesystem

%description driverless
Contains backends and drivers for driverless implementation for cups-filters,
which makes driverless printers to be seen when listing printers nearby and gives
a specific generated driver for driverless printer in the local network. They are
tools for backward compatibility with applications which don't handle CUPS temporary
queues.

%prep
%autosetup -S git

%build
# work-around Rpath
./autogen.sh

%configure --enable-driverless \
           --enable-universal-cups-filter \
           --disable-mutool \
           --disable-rpath \
           --disable-silent-rules \
           --disable-static

%make_build

%install
%make_install

# 2229776 - Add textonly driver back, but as lftocrlf
install -p -m 0755 %{SOURCE2} %{buildroot}%{_cups_serverbin}/filter/lftocrlf
install -p -m 0644 %{SOURCE1} %{buildroot}%{_datadir}/ppd/cupsfilters/lftocrlf.ppd

# LSB3.2 requires /usr/bin/foomatic-rip,
# create it temporarily as a relative symlink
# we may use symlink to universal filter, but LSB is about guaranteed compatibility set
# among distibutions, so rather have the strict foomatic-rip filter...
ln -sf %{_cups_serverbin}/filter/foomatic-rip %{buildroot}%{_bindir}/foomatic-rip
#ln -sf %%{_cups_serverbin}/filter/universal %%{buildroot}%%{_bindir}/foomatic-rip

# remove license files which are in %%pkgdocdir
rm -f %{buildroot}%{_pkgdocdir}/{COPYING,NOTICE,LICENSE}

# remove INSTALL since it is unnecessary
rm -f %{buildroot}%{_pkgdocdir}/INSTALL

# remove CHANGES-1.x.md, since it is carried by a dependency
rm -f %{buildroot}%{_pkgdocdir}/CHANGES-1.x.md


%check
make check


%files
%license COPYING LICENSE NOTICE
%doc AUTHORS ABOUT-NLS CHANGES.md CONTRIBUTING.md DEVELOPING.md README.md
%{_bindir}/foomatic-rip
%attr(0744,root,root) %{_cups_serverbin}/backend/beh
# all backends needs to be run only as root because of kerberos
%attr(0744,root,root) %{_cups_serverbin}/backend/parallel
# Serial backend needs to run as root (bug #212577#c4).
%attr(0744,root,root) %{_cups_serverbin}/backend/serial
%attr(0755,root,root) %{_cups_serverbin}/filter/bannertopdf
%attr(0755,root,root) %{_cups_serverbin}/filter/commandtoescpx
%attr(0755,root,root) %{_cups_serverbin}/filter/commandtopclx
%attr(0755,root,root) %{_cups_serverbin}/filter/foomatic-rip
%attr(0755,root,root) %{_cups_serverbin}/filter/gstopdf
%attr(0755,root,root) %{_cups_serverbin}/filter/gstopxl
%attr(0755,root,root) %{_cups_serverbin}/filter/gstoraster
%attr(0755,root,root) %{_cups_serverbin}/filter/imagetopdf
%attr(0755,root,root) %{_cups_serverbin}/filter/imagetops
%attr(0755,root,root) %{_cups_serverbin}/filter/imagetoraster
# 2229776 - Add textonly driver back, but as lftocrlf
%attr(0755,root,root) %{_cups_serverbin}/filter/lftocrlf
%attr(0755,root,root) %{_cups_serverbin}/filter/pclmtoraster
%attr(0755,root,root) %{_cups_serverbin}/filter/pdftopdf
%attr(0755,root,root) %{_cups_serverbin}/filter/pdftops
%attr(0755,root,root) %{_cups_serverbin}/filter/pdftoraster
%attr(0755,root,root) %{_cups_serverbin}/filter/pwgtopclm
%attr(0755,root,root) %{_cups_serverbin}/filter/pwgtopdf
%attr(0755,root,root) %{_cups_serverbin}/filter/pwgtoraster
%attr(0755,root,root) %{_cups_serverbin}/filter/rastertoescpx
%attr(0755,root,root) %{_cups_serverbin}/filter/rastertopclx
%attr(0755,root,root) %{_cups_serverbin}/filter/rastertops
%attr(0755,root,root) %{_cups_serverbin}/filter/texttopdf
%attr(0755,root,root) %{_cups_serverbin}/filter/texttops
%attr(0755,root,root) %{_cups_serverbin}/filter/texttotext
%attr(0755,root,root) %{_cups_serverbin}/filter/universal
%{_datadir}/cups/drv/cupsfilters.drv
%{_datadir}/cups/mime/cupsfilters.types
%{_datadir}/cups/mime/cupsfilters.convs
%{_datadir}/cups/mime/cupsfilters-universal-postscript.convs
%{_datadir}/cups/mime/cupsfilters-universal.convs
%{_datadir}/ppd/cupsfilters
# escp.h and pcl.h are required during runtime, because
# CUPS PPD compiler (ppdc) uses them for generating drivers
# per request from cupsfilters.drv file
%{_datadir}/ppdc/escp.h
%{_datadir}/ppdc/pcl.h
%{_mandir}/man1/foomatic-rip.1.*

%files driverless
%license COPYING LICENSE NOTICE
%{_bindir}/driverless
%{_bindir}/driverless-fax
%{_cups_serverbin}/backend/driverless
%{_cups_serverbin}/backend/driverless-fax
%{_cups_serverbin}/driver/driverless
%{_cups_serverbin}/driver/driverless-fax
%{_mandir}/man1/driverless.1.*


%changelog
* Tue May 07 2024 daviddavid <daviddavid> 2.0.0-1.mga10
+ Revision: 2062723
- new version: 2.0.0
- split out in a separate pkg driverless stuff
- libcupsfilter, libppd and cups-browsed were splitted in their own source pkgs

* Mon May 22 2023 ns80 <ns80> 1.28.16-6.mga9
+ Revision: 1957700
- add patches from Ubuntu for CVE-2023-24805 (mga#31939)

* Sun May 07 2023 daviddavid <daviddavid> 1.28.16-5.mga9
+ Revision: 1956058
- require-cxx17.patch: qpdf dependency is using std::string_view
  which is a c++17 feature... so we can't use c++11... Maybe it
  made sense to force c++11 at some point when it was not default,
  but with new compilers, we are actually downgrading features sets.

* Mon Dec 12 2022 ns80 <ns80> 1.28.16-4.mga9
+ Revision: 1920981
- rebuild for new libtiff

* Mon Oct 24 2022 ghibo <ghibo> 1.28.16-3.mga9
+ Revision: 1899153
- Rebuild against latest libpoppler

* Wed Oct 19 2022 ghibo <ghibo> 1.28.16-2.mga9
+ Revision: 1897597
- Rebuild against qpdf 11.1.1

* Thu Sep 22 2022 luigiwalser <luigiwalser> 1.28.16-1.mga9
+ Revision: 1891531
- 1.28.16 (sync with fedora)

* Mon Apr 25 2022 tv <tv> 1.28.15-1.mga9
+ Revision: 1853144
- 1.28.15

* Thu Apr 07 2022 tv <tv> 1.28.14-1.mga9
+ Revision: 1847481
- 1.28.14

* Wed Mar 30 2022 tv <tv> 1.28.13-1.mga9
+ Revision: 1834313
- 1.28.13

* Fri Mar 11 2022 luigiwalser <luigiwalser> 1.28.12-1.mga9
+ Revision: 1790472
- 1.28.12

* Wed Jan 19 2022 tv <tv> 1.28.11-1.mga9
+ Revision: 1769007
- 1.28.11

* Wed Sep 22 2021 tv <tv> 1.28.10-1.mga9
+ Revision: 1746174
- 1.28.10
- Only poppler-cpp is needed

* Thu Jul 22 2021 tv <tv> 1.28.9-2.mga9
+ Revision: 1737400
- pdftopdf doesn't handle "page-range=10-2147483647" correctly

* Mon Jun 21 2021 tv <tv> 1.28.9-1.mga9
+ Revision: 1731594
- 1.28.9

* Wed May 26 2021 tv <tv> 1.28.8-1.mga9
+ Revision: 1728397
- 1.28.8

* Sun May 02 2021 tv <tv> 1.28.7-2.mga9
+ Revision: 1720910
- cups-browsed doesn't save "*-default" options (rhbz#1954524)

* Wed Jan 27 2021 tv <tv> 1.28.7-1.mga8
+ Revision: 1673657
- 1.28.7, urftopdf nor pdftoopvp aren't compiled anymore

* Wed Dec 09 2020 tv <tv> 1.28.6-1.mga8
+ Revision: 1654850
- 1.28.6

* Tue Dec 01 2020 tv <tv> 1.28.5-6.mga8
+ Revision: 1651295
- fix deps

* Tue Dec 01 2020 tv <tv> 1.28.5-5.mga8
+ Revision: 1651101
- switch to systemd macro for scriptlets
- filters using ijs were removed, removed the dep

* Tue Nov 24 2020 tv <tv> 1.28.5-4.mga8
+ Revision: 1648909
- fix various memory issues within cups-browsed
- BR git-core instead of full git

* Tue Nov 03 2020 tv <tv> 1.28.5-3.mga8
+ Revision: 1642082
- 1.28.5
- cups-browsed crashing (rhbz#1881365)

* Tue Oct 27 2020 tv <tv> 1.28.2-3.mga8
+ Revision: 1639845
- foomatic-rip files up /var/spool/tmp with temporary files (rhbz#1891720)

* Thu Sep 17 2020 tv <tv> 1.28.2-2.mga8
+ Revision: 1628003
- driverless cannot generate ppd for dns-sd based uris (rhbz#1879147)

* Wed Sep 16 2020 tv <tv> 1.28.2-1.mga8
+ Revision: 1626888
- 1.28.2

* Sun Aug 30 2020 tv <tv> 1.28.1-1.mga8
+ Revision: 1619711
- 1.28.1 - added driverless fax support

* Mon Aug 24 2020 tv <tv> 1.27.5-4.mga8
+ Revision: 1618548
- use configure option instead of downstream, cups-browsed.conf editing, patch
- the exact path in cups-browsed manpage was removed, use the patch removing it instead of downstream one
- use configure option to dont save queues between restarts instead of downstream patch reverting the issue
- memory leaks patch is from upstream too

* Wed Aug 19 2020 tv <tv> 1.27.5-3.mga8
+ Revision: 1615942
- cups-browsed leaks memory (rhbz#1867412)

* Mon Jul 20 2020 tv <tv> 1.27.5-2.mga8
+ Revision: 1607443
- PPD generators creates invalid cupsManualCopies entry (rhbz#1848575)

* Tue Jun 09 2020 tv <tv> 1.27.5-1.mga8
+ Revision: 1591196
- 1.27.5

* Tue Apr 14 2020 tv <tv> 1.27.4-2.mga8
+ Revision: 1567304
- rebuild for new qpdf

* Tue Apr 14 2020 tv <tv> 1.27.4-1.mga8
+ Revision: 1567286
- 1.27.4
- memory issues in cups-browsed

* Mon Apr 06 2020 tv <tv> 1.27.3-2.mga8
+ Revision: 1565148
- make avahi and nss-mdns recommended - so users with older printers can
  install cups without it

* Mon Mar 23 2020 tv <tv> 1.27.3-1.mga8
+ Revision: 1559097
- 1.27.3

* Fri Mar 20 2020 tv <tv> 1.27.2-3.mga8
+ Revision: 1558212
- fix deps

* Fri Mar 20 2020 tv <tv> 1.27.2-2.mga8
+ Revision: 1558170
- fix leaks in cups-browsed
- add require on nss-mdns

* Tue Mar 03 2020 tv <tv> 1.27.2-1.mga8
+ Revision: 1553406
- 1.27.2

* Sat Feb 29 2020 tv <tv> 1.27.1-3.mga8
+ Revision: 1552066
- foomatic-rip handles empty files in bad way (rhbz#1806862)

* Thu Feb 20 2020 umeabot <umeabot> 1.27.1-2.mga8
+ Revision: 1545304
- Mageia 8 Mass Rebuild

* Tue Feb 18 2020 tv <tv> 1.27.1-1.mga8
+ Revision: 1541218
- 1.27.1

* Tue Jan 28 2020 tv <tv> 1.27.0-1.mga8
+ Revision: 1484601
- 1.27.0
- add post scriptlet for update
- we're ready for poppler-0.84; use FC patch
+ wally <wally>
- rebuild for poppler 0.84.0
- replace deprecated %%configure2_5x

* Mon Dec 23 2019 wally <wally> 1.22.5-12.mga8
+ Revision: 1469661
- rebuild for poppler 0.83.0

* Wed Nov 27 2019 tv <tv> 1.22.5-11.mga8
+ Revision: 1463120
- Updated cups-browsed in RHEL 7.7 leaks sockets (rhbz#1776271)

* Sat Nov 23 2019 tv <tv> 1.22.5-10.mga8
+ Revision: 1462334
- rebuilt for qpdf-9.1.0

* Tue Nov 12 2019 tv <tv> 1.22.5-9.mga8
+ Revision: 1459652
- Epson ET 7700 reports pwg support, but pwg does not work (rhbz#1756726)

* Thu Oct 31 2019 wally <wally> 1.22.5-8.mga8
+ Revision: 1457164
- rebuild for new poppler 0.82.0

* Thu Oct 17 2019 tv <tv> 1.22.5-7.mga8
+ Revision: 1454247
- gs 9.27 now uses setfilladjust2

* Thu Oct 10 2019 wally <wally> 1.22.5-6.mga8
+ Revision: 1451104
- rebuild for poppler 0.81.0

* Thu Oct 03 2019 tv <tv> 1.22.5-5.mga8
+ Revision: 1449051
- add support for incoming qpdf-9.0.0
- pdftopdf output should not be encrypted
- require colord, because it is needed for ICC profiles for filters

* Thu Sep 19 2019 wally <wally> 1.22.5-4.mga8
+ Revision: 1443901
- rebuild for poppler 0.80.0

* Fri Aug 30 2019 tv <tv> 1.22.5-3.mga8
+ Revision: 1435310
- foomatic-rip segfaults when env variable PRINTER is not defined (rhbz#1740122)
- remove unneeded scriptlet

* Sun Jul 14 2019 wally <wally> 1.22.5-2.mga8
+ Revision: 1421250
- rebuild for poppler 0.78.0

* Thu Apr 11 2019 tv <tv> 1.22.5-1.mga7
+ Revision: 1388347
- 1.22.5

* Wed Mar 27 2019 tv <tv> 1.22.3-1.mga7
+ Revision: 1380550
- new release

* Mon Feb 18 2019 wally <wally> 1.22.0-4.mga7
+ Revision: 1368131
- rebuild for new poppler 0.74.0

* Sun Feb 03 2019 tv <tv> 1.22.0-3.mga7
+ Revision: 1362797
- cups-brf needs to be run as root

* Sat Jan 26 2019 wally <wally> 1.22.0-2.mga7
+ Revision: 1361104
- rebuild for new poppler 0.73.0

* Mon Jan 21 2019 luigiwalser <luigiwalser> 1.22.0-1.mga7
+ Revision: 1358575
- 1.22.0

* Sat Dec 29 2018 luigiwalser <luigiwalser> 1.21.6-1.mga7
+ Revision: 1346432
- 1.21.6
- remove upstream patch

* Mon Dec 17 2018 tv <tv> 1.21.5-1.mga7
+ Revision: 1342229
- 1.21.5

* Sat Dec 08 2018 wally <wally> 1.21.3-5.mga7
+ Revision: 1338975
- rebuild for new poppler 0.72.0

* Sun Nov 18 2018 tv <tv> 1.21.3-4.mga7
+ Revision: 1330651
- links in manpages are wrong

* Sat Nov 17 2018 wally <wally> 1.21.3-3.mga7
+ Revision: 1330445
- rebuild for new poppler 0.71.0
- add patch to fix build with poppler >= 0.71

* Fri Nov 02 2018 wally <wally> 1.21.3-2.mga7
+ Revision: 1327697
- add patch to build without '-fpermissive'

* Wed Oct 31 2018 wally <wally> 1.21.3-1.mga7
+ Revision: 1326999
- new version 1.21.3
- add upstream patch to fix build with poppler >= 0.69.0
- build with -fpermissive for now to get pkg to build with gcc 8

* Wed Oct 03 2018 tv <tv> 1.21.2-2.mga7
+ Revision: 1316245
- rebuild for new qpdf
- 1.21.2
- cups-filters: Sticky EOF behavior in glibc breaks descriptor concatenation
  using dup2 (breaks printing) (rhbz#1628255)
- correcting license
- hybrid pdftops filter requires poppler and ghostscript for run
- cups-browsed needs to have cups.service to run

* Sun Sep 23 2018 umeabot <umeabot> 1.20.3-3.mga7
+ Revision: 1297370
- Mageia 7 Mass Rebuild

* Sun Apr 15 2018 kekepower <kekepower> 1.20.3-2.mga7
+ Revision: 1219054
- Rebuild for new Poppler

* Fri Apr 13 2018 tv <tv> 1.20.3-1.mga7
+ Revision: 1218362
- new release

* Thu Apr 05 2018 tv <tv> 1.20.2-1.mga7
+ Revision: 1215497
- drop old flag fix
- 1.20.2
- fixing discovering of remote CUPS queues and LDAP queues
- dependency on poppler is now only recommended

* Tue Mar 27 2018 tv <tv> 1.20.1-2.mga7
+ Revision: 1212757
- new release

* Mon Feb 19 2018 kekepower <kekepower> 1.20.0-2.mga7
+ Revision: 1202928
- Rebuild for new qpdf

* Wed Jan 31 2018 tv <tv> 1.20.0-1.mga7
+ Revision: 1198221
- new release

* Tue Jan 23 2018 tv <tv> 1.19.0-1.mga7
+ Revision: 1196566
- new release

* Wed Jan 10 2018 ns80 <ns80> 1.17.9-4.mga7
+ Revision: 1192053
- rebuild for new poppler

* Thu Jan 04 2018 tv <tv> 1.17.9-3.mga7
+ Revision: 1190243
- set CreateIPPPrintQueues to ALL and LocalRemoteCUPSQueueNaming to RemoteName (rhbz#1529680)

* Wed Nov 22 2017 tv <tv> 1.17.9-2.mga7
+ Revision: 1178598
- upstream 1413 - Propagation of location doesn't work

* Wed Oct 18 2017 tv <tv> 1.17.9-1.mga7
+ Revision: 1172630
- new release
- new release

* Thu Oct 12 2017 tv <tv> 1.17.8-3.mga7
+ Revision: 1171285
- rebuild for poppler 0.60.1
- removing Provides foomatic-filters
- upstream 1413 - Propagation of location doesn't work

* Tue Oct 03 2017 tv <tv> 1.17.8-1.mga7
+ Revision: 1167923
- new release

* Wed Sep 20 2017 tv <tv> 1.17.7-1.mga7
+ Revision: 1156310
- new release

* Sat Sep 16 2017 tv <tv> 1.17.2-4.mga7
+ Revision: 1154539
- rebuild for poppler 0.59.0
- rebuild for new poppler

* Thu Sep 07 2017 tv <tv> 1.17.2-1.mga7
+ Revision: 1151783
- new release

* Tue Sep 05 2017 tv <tv> 1.16.3-1.mga7
+ Revision: 1151337
- new release

* Mon Aug 07 2017 neoclust <neoclust> 1.14.1-3.mga7
+ Revision: 1138666
- Rebuild with build fixes

* Fri Aug 04 2017 luigiwalser <luigiwalser> 1.14.1-2.mga7
+ Revision: 1135000
- rebuild against updated qpdf

* Mon Jul 17 2017 tv <tv> 1.14.1-1.mga7
+ Revision: 1124203
- fix building with gcc5
- new release

* Fri May 26 2017 neoclust <neoclust> 1.13.4-2.mga6
+ Revision: 1104821
- Rebuild to see if it help to fix a crash

* Sun Mar 26 2017 tv <tv> 1.13.4-1.mga6
+ Revision: 1094860
- 1.13.4
- Added queues are not marked as remote ones (rhbz#1426567)

* Thu Jan 05 2017 tv <tv> 1.13.2-1.mga6
+ Revision: 1080230
- new release

* Mon Jan 02 2017 luigiwalser <luigiwalser> 1.13.0-2.mga6
+ Revision: 1079506
- rebuild for poppler

* Thu Dec 15 2016 tv <tv> 1.13.0-1.mga6
+ Revision: 1075323
- new release
- explicitely disable mutool as we don't have mupdf anymore

* Mon Nov 28 2016 luigiwalser <luigiwalser> 1.11.4-2.mga6
+ Revision: 1070612
- rebuild for poppler

* Fri Sep 30 2016 tv <tv> 1.11.4-1.mga6
+ Revision: 1057857
- new release

* Fri Sep 16 2016 tv <tv> 1.11.3-1.mga6
+ Revision: 1053443
- new version

* Thu Sep 15 2016 tv <tv> 1.11.2-1.mga6
+ Revision: 1053130
- new version

* Sat Aug 13 2016 luigiwalser <luigiwalser> 1.9.0-2.mga6
+ Revision: 1046172
- test rebuild for poppler

* Sat Jun 11 2016 tv <tv> 1.9.0-1.mga6
+ Revision: 1021135
- new release

* Wed May 25 2016 luigiwalser <luigiwalser> 1.8.3-3.mga6
+ Revision: 1018536
- rebuild for poppler

* Mon May 09 2016 luigiwalser <luigiwalser> 1.8.3-2.mga6
+ Revision: 1011747
- rebuild for poppler

* Tue Mar 29 2016 tv <tv> 1.8.3-1.mga6
+ Revision: 996094
- new release

* Sun Feb 14 2016 tv <tv> 1.8.2-1.mga6
+ Revision: 959968
- 1.8.2

* Fri Jan 22 2016 tv <tv> 1.8.1-1.mga6
+ Revision: 926481
- new release

* Fri Jan 22 2016 tv <tv> 1.8.0-1.mga6
+ Revision: 926415
- new release

* Tue Jan 19 2016 tv <tv> 1.7.0-1.mga6
+ Revision: 925921
- new release

* Mon Jan 18 2016 luigiwalser <luigiwalser> 1.6.0-2.mga6
+ Revision: 925489
- rebuild for qpdf

* Thu Jan 14 2016 tv <tv> 1.6.0-1.mga6
+ Revision: 923019
- adjust file list
- new release
- new release

* Fri Jan 01 2016 luigiwalser <luigiwalser> 1.5.0-2.mga6
+ Revision: 917800
- rebuild for poppler

* Sat Dec 19 2015 tv <tv> 1.5.0-1.mga6
+ Revision: 912074
- new release

* Tue Dec 15 2015 tv <tv> 1.4.0-1.mga6
+ Revision: 910755
- new release

* Sun Dec 13 2015 luigiwalser <luigiwalser> 1.3.0-2.mga6
+ Revision: 910248
- add upstream patch to fix incomplete escaping in foomatic-rip

* Thu Dec 10 2015 tv <tv> 1.3.0-1.mga6
+ Revision: 909342
- new release
- notice that this package is synced with FC

* Fri Nov 27 2015 tv <tv> 1.2.0-1.mga6
+ Revision: 906458
- 1.2.0

* Thu Oct 29 2015 tv <tv> 1.1.0-1.mga6
+ Revision: 896177
- new release

* Sun Sep 13 2015 tv <tv> 1.0.76-1.mga6
+ Revision: 878893
- new release

* Tue Sep 08 2015 tv <tv> 1.0.75-1.mga6
+ Revision: 874039
- new release

* Fri Aug 28 2015 tv <tv> 1.0.74-1.mga6
+ Revision: 870414
- new release
- new release

* Sat Jul 25 2015 tv <tv> 1.0.71-2.mga6
+ Revision: 857578
- switch to %%autopatch -p0
- rebuild for new poppler
- new release

* Sat Jul 04 2015 luigiwalser <luigiwalser> 1.0.71-1.mga6
+ Revision: 850569
- 1.0.71 (fixes CVE-2015-3279)

* Mon Jun 29 2015 tv <tv> 1.0.70-1.mga6
+ Revision: 847563
- 1.0.70 (fixes CVE-2015-3258)

* Thu Jun 25 2015 tv <tv> 1.0.69-2.mga6
+ Revision: 842817
- rebuild for new poppler

* Sun Jun 21 2015 tv <tv> 1.0.69-1.mga6
+ Revision: 837659
- new release

* Fri Mar 13 2015 luigiwalser <luigiwalser> 1.0.67-1.mga5
+ Revision: 818482
- 1.0.67 (fixes lp#1427344)

* Wed Mar 04 2015 tv <tv> 1.0.66-1.mga5
+ Revision: 817628
- new release

* Wed Feb 18 2015 tv <tv> 1.0.65-1.mga5
+ Revision: 815634
- new version

* Wed Feb 18 2015 neoclust <neoclust> 1.0.61-2.mga5
+ Revision: 815609
- Remove wrong obsoletes

* Thu Oct 23 2014 tv <tv> 1.0.61-1.mga5
+ Revision: 792586
- new release
- drop merged patch

* Wed Oct 15 2014 umeabot <umeabot> 1.0.58-5.mga5
+ Revision: 742159
- Second Mageia 5 Mass Rebuild

* Wed Oct 08 2014 luigiwalser <luigiwalser> 1.0.58-4.mga5
+ Revision: 737588
- add upstream patch to fix segfault in foomatic-rip (upstream bug #1227)

* Thu Sep 18 2014 umeabot <umeabot> 1.0.58-3.mga5
+ Revision: 693712
- Rebuild to fix library dependencies

* Tue Sep 16 2014 umeabot <umeabot> 1.0.58-2.mga5
+ Revision: 678634
- Mageia 5 Mass Rebuild

* Fri Aug 22 2014 tv <tv> 1.0.58-1.mga5
+ Revision: 666360
- new release

* Thu Jul 31 2014 tv <tv> 1.0.55-1.mga5
+ Revision: 658807
- new release

* Fri Jun 20 2014 tv <tv> 1.0.54-3.mga5
+ Revision: 638233
- sync patches with FC

* Sun Jun 15 2014 ovitters <ovitters> 1.0.54-2.mga5
+ Revision: 636465
- obsoletes printer-filters,printer-filters-doc

* Wed Jun 11 2014 tv <tv> 1.0.54-1.mga5
+ Revision: 635582
- new release

* Tue Jun 03 2014 luigiwalser <luigiwalser> 1.0.53-2.mga5
+ Revision: 632611
- restore patch for rhbz#768811 from fedora

* Mon Apr 28 2014 tv <tv> 1.0.53-1.mga5
+ Revision: 618749
- disable testsuite again
- new release
- reenable test suite

* Mon Apr 14 2014 tv <tv> 1.0.52-1.mga5
+ Revision: 614275
- new release

* Fri Apr 04 2014 tv <tv> 1.0.51-1.mga5
+ Revision: 611614
- new release

* Fri Mar 28 2014 tv <tv> 1.0.50-1.mga5
+ Revision: 609160
- new release

* Thu Mar 27 2014 tv <tv> 1.0.49-1.mga5
+ Revision: 608904
- new release

* Thu Mar 20 2014 tv <tv> 1.0.48-1.mga5
+ Revision: 606264
- adjust file list
- new release
- sync patches with RH
- new release
- sync patches with RH

* Thu Mar 13 2014 tv <tv> 1.0.46-3.mga5
+ Revision: 603246
- rebuild for "new" libqpdf

* Sat Feb 22 2014 tv <tv> 1.0.46-2.mga5
+ Revision: 595473
- fix printing: configure needs /bin/gs (mga#11684)

* Thu Feb 20 2014 tv <tv> 1.0.46-1.mga5
+ Revision: 595164
- new release

* Sat Feb 15 2014 tv <tv> 1.0.45-1.mga5
+ Revision: 591607
- new release

* Fri Feb 07 2014 tv <tv> 1.0.44-2.mga5
+ Revision: 584974
- fix upgrade

* Fri Feb 07 2014 tv <tv> 1.0.44-1.mga5
+ Revision: 584956
- new release
- obsoletes foomatic-filters
- add /usr/bin/foomatic-rip symlink, due to LSB3.2 (rhbz#1052452)

* Tue Nov 19 2013 tv <tv> 1.0.41-3.mga5
+ Revision: 551952
- adjust filter costs so application/vnd.adobe-read-postscript input
  doesn't go via pstotiff (rhbz#1008166)

* Tue Nov 19 2013 tv <tv> 1.0.41-2.mga4
+ Revision: 551865
- fix memory leaks in cups-browsed (rhbz#1027317)
- include dbus so that colord support works (rhbz#1026928)

* Wed Oct 30 2013 tv <tv> 1.0.41-1.mga4
+ Revision: 548025
- new release

* Tue Oct 22 2013 umeabot <umeabot> 1.0.40-3.mga4
+ Revision: 542055
- Mageia 4 Mass Rebuild

* Mon Oct 14 2013 tv <tv> 1.0.40-2.mga4
+ Revision: 496793
- fix PDF landscape printing (rhbz#768811)

* Fri Oct 11 2013 tv <tv> 1.0.40-1.mga4
+ Revision: 495218
- new release
- use new "hybrid" pdftops renderer

* Thu Oct 03 2013 tv <tv> 1.0.39-1.mga4
+ Revision: 490971
- new release

* Thu Oct 03 2013 tv <tv> 1.0.38-2.mga4
+ Revision: 490877
- sync with FC:
  o Use IPP notifications for BrowsePoll when possible (rhbz#975241)
  o Fixes for some printf-type format mismatches (rhbz#1014093)
- patch 1: fix landscape printing for PDFs (bug rhbz#768811)

* Thu Sep 12 2013 tv <tv> 1.0.38-1.mga4
+ Revision: 478016
- new release

* Sat Aug 31 2013 tv <tv> 1.0.37-2.mga4
+ Revision: 473751
- conflicts with older ghostscript-common for upgrade

* Fri Aug 30 2013 tv <tv> 1.0.37-1.mga4
+ Revision: 473432
- disable test suite
- new release
- run make check
- new release

* Wed Jul 31 2013 fwang <fwang> 1.0.35-5.mga4
+ Revision: 461346
- rebuild for new poppler

* Sat Jul 27 2013 tv <tv> 1.0.35-4.mga4
+ Revision: 458740
- requires cups-filesystem instead of cups

* Sat Jul 27 2013 tv <tv> 1.0.35-3.mga4
+ Revision: 458736
- sync with FC:
  o added support for page-label (rhz#987515)
  o add cups-browsed(8) and cups-browsed.conf(5)
  o don't reverse lookup IP address in URI (rhz#975822)

* Sat Jul 20 2013 fwang <fwang> 1.0.35-2.mga4
+ Revision: 456552
- more patch
- more patch
- add include
- update format
- try fix building with recent poppler
- rebuild for new poppler
+ tv <tv>
- fix URL

* Sat Jun 29 2013 tv <tv> 1.0.35-1.mga4
+ Revision: 448307
- new release

* Thu Jun 20 2013 tv <tv> 1.0.34-8.mga4
+ Revision: 445204
- fix the note we add in cups-browsed.conf

* Thu Jun 13 2013 tv <tv> 1.0.34-7.mga4
+ Revision: 442559
- use our services macros rather than FC ones)

* Thu Jun 13 2013 tv <tv> 1.0.34-6.mga4
+ Revision: 442544
- prevent %%systemd_(pre|post)un to fail (ignoring status)

* Thu Jun 13 2013 tv <tv> 1.0.34-5.mga4
+ Revision: 442524
- obsolete php-cups as it has been picked by cups-filters but is broken
- cupsfilters.drv needs ppdc/pcl.h
- pstopdf requires bc
- mem leaks fixes from FC

* Tue Jun 04 2013 fwang <fwang> 1.0.34-4.mga4
+ Revision: 437124
- fix conflicts

* Tue Jun 04 2013 tv <tv> 1.0.34-3.mga4
+ Revision: 437104
- conflicts with older cups

* Tue Jun 04 2013 fwang <fwang> 1.0.34-2.mga4
+ Revision: 437054
- update requires

* Wed May 29 2013 tv <tv> 1.0.34-1.mga4
+ Revision: 430294
- imported package cups-filters


* Tue May 28 2013 Thierry Vignaud <tv@mageia.org> 1.0.34-1.mga4
- import from FC
